#
# spec file for package kirigami2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libKF5Kirigami2-5
%define _tar_path 5.76
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kirigami2
Version:        5.76.0
Release:        bp153.3.2.1
Summary:        Set of QtQuick components
License:        LGPL-2.1-or-later
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch0:         0001-Revert-Watch-for-language-change-events-and-forward-.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-dont-use-__-yet.patch
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(Qt5Concurrent) >= 5.12.0
BuildRequires:  cmake(Qt5Core) >= 5.12.0
BuildRequires:  cmake(Qt5DBus) >= 5.12.0
BuildRequires:  cmake(Qt5Gui) >= 5.12.0
BuildRequires:  cmake(Qt5Quick) >= 5.12.0
BuildRequires:  cmake(Qt5QuickControls2) >= 5.12.0
BuildRequires:  cmake(Qt5Svg) >= 5.12.0
BuildRequires:  cmake(Qt5Test) >= 5.12.0
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols2
Recommends:     %{name}-lang = %{version}
%if %{with lang}
BuildRequires:  cmake(Qt5LinguistTools) >= 5.12.0
%endif

%description
QtQuick plugins to build user interfaces based on the KDE UX guidelines.

%package -n %{lname}
Summary:        Set of QtQuick components
Group:          System/Libraries
Recommends:     %{name} = %{version}

%description -n %{lname}
QtQuick plugins to build user interfaces based on the KDE UX guidelines.
Based on Qt Quick Controls 2. This package contains the base shared libraries.

%package devel
Summary:        Development package for kirigami
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}

%description devel
QtQuick plugins to build user interfaces based on the KDE UX guidelines.
Development files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%if %{with lang}
%find_lang libkirigami2plugin --with-qt --without-mo
%endif

%if %{with lang}
%files lang -f libkirigami2plugin.lang
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%license LICENSES/*
%dir %{_kf5_sharedir}/kdevappwizard/
%{_kf5_qmldir}/
%{_kf5_sharedir}/kdevappwizard/templates/

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Kirigami2.so.*

%files devel
%license LICENSES/*
%dir %{_kf5_includedir}/Kirigami2/
%{_kf5_includedir}/Kirigami2/*
%{_kf5_libdir}/libKF5Kirigami2.so
%{_kf5_mkspecsdir}/qt_Kirigami2.pri
%{_libdir}/cmake/KF5Kirigami2/

%changelog
* Fri Feb 19 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to not use ?? which requires Qt 5.15
  * 0001-dont-use-__-yet.patch
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes since 5.75.0, only listing bugfixes:
  * Also set a maximumWidth for icons in global drawer (kde#428658)
  * Don't alter Item in code called from Item's destructor (kde#428481)
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes since 5.74.0, only listing bugfixes:
  * Hide breadcrumbs separator line if buttons layout is visible but 0 width (kde#426738)
  * Remove actions and delegates from ToolBarLayout when they get destroyed (kde#425670)
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes since 5.73.0, only listing bugfixes:
  * Add a property to ToolBarLayout to control how to deal with item height (kde#425675)
  * new logic to remove acceleration marks (kde#420409)
  * Do not override Heading pixel size in BreadCrumbControl (kde#404396)
  * [passivenotification] Set explicit padding (kde#419391)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Too many changes to list here.
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Too many changes since 5.71.0, only listing bugfixes:
  * [overlaysheet] Avoid fractional height for contentLayout (kde#422965)
  * Fix OverlaySheet closing when clicking inside layout (kde#421848)
* Fri Jun 19 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add patch to fix crashes of several settings modules, with Qt
  5.12 at least (boo#1167690, kde#419008):
  * 0001-Revert-Watch-for-language-change-events-and-forward-.patch
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Too many changes since 5.70.0, only listing bugfixes:
  * Always use Window colorset for AbstractApplicationHeader (kde#421573)
- Drop upstream patch:
  * fix-import-in-PlaceholderMessage.patch
* Wed May 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix PlaceholderMessage with Qt 5.12:
  * fix-import-in-PlaceholderMessage.patch
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Too many changes since 5.69.0, only listing bugfixes:
  * vertically center sheets if theiy don't have a scrollbar (kde#419804)
  * Various fixes to new Cards (kde#420406)
  * Use ShadowedRectangle for Card backgrounds (kde#415526)
  * never close when the click is inside the sheet contents (kde#419691)
  * sheet must be under other popups (kde#419930)
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Too many changes since 5.68.0, only listing bugfixes:
  * simplify header resizing (kde#419124)
  * Fix undefined check in global drawer menu mode (kde#417956)
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Too many changes since 5.67.0, only listing bugfixes:
  * Icon: fix rendering of image: urls on High DPI (kde#417647)
  * Do not crash when icon's width or height is 0 (kde#417844)
  * properly sync size hints with state machine (kde#417351)
- Drop 0001-make-headerParent-correctly-alignedwhen-there-is-a-s.patch
* Mon Feb 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch 0001-make-headerParent-correctly-alignedwhen-there-is-a-s.patch
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Too many changes since 5.66.0, only listing bugfixes:
  * Clip the flickable parent item (kde#416877)
  * proper size hint for the gridlayout (kde#416860)
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Too many changes since 5.65.0, only listing bugfixes:
  * ActionToolBar: Only show the overflow button if there are visible items in the menu (kde#415412)
  * reintroduce the collapse button (kde#415074)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Too many changes since 5.64.0, only listing bugfixes:
  * Fix default card background (kde#414329)
  * Make QmlComponentsPool one instance per engine (kde#414003)
  * Vertically center left actions in ActionTextField (kde#413769)
* Wed Nov 20 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.64.1
  * New bugfix release
- Changes since 5.64.0:
  * Make QmlComponentsPool one instance per engine (kde#414003)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Too many changes since 5.63.0, only listing bugfixes:
  * highlight on mouseover only when more than one page (kde#410673)
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes since 5.62.0, only listing bugfixes:
  * more z (kde#411832)
  * port away from deprecated Kirigami.ApplicationHeader (kde#405571)
  * some margin on the right (kde#409630)
  * don't make list items look inactive (kde#408191)
  * Layout.fillWidth should be done by the client (kde#411188)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Replace the custom overflow button with PrivateActionToolButton in ActionToolBar
  * If a submenu action has an icon set, make sure to also display it
  * [Separator] Match Breeze borders' color
  * Add Kirigami ListSectionHeader component
  * Fix context menu button for pages not showing up
  * Fix PrivateActionToolButton with menu not clearing checked state properly
  * Use QLatin1String + QString::remove operates on the same object, no need to reassign
  * Fix supported OS attributes for api.kde.org
  * remove references from the icon qrc to missing icons.
  * allow to set custom icon for the left drawer handle
  * Rework the visibleActions logic in SwipeListItem
  * Allow usage of QQC2 actions on Kirigami components and now make K.Action based on QQC2.Action
  * bump import
  * Add handle icons
  * Kirigami.Icon: Fix loading bigger images when source is a URL (kde#407409)
  * Add icon used by Kirigami.AboutPage
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * reintroduce 00415d3345a with proper names
  * Partially revert 00415d3345a to fix regression
  * Sync to diff in D22868 (pushed wrong branch)
  * Revamp Kirigami.AboutPage
  * Consistently use Units.toolTipDelay instead of hardcoded values
  * properly size the card contents when the card size is constrained
  * hide ripple when we don't want items clickable
  * make handle follow arbitrary height of the drawer
  * Fix typo
  * [SwipeListItem] Take into account scrollbar visibility and form factor for handle and inline actions
  * Remove scaling of iconsize unit for isMobile
  * always show back button on layers>1
  * Fix 2 typos
  * hide actions with submenus from more menu
  * default ActionToolBar position ot Header
  * big z to not appear under dialogs
  * use opacity to hide buttons that don't fit
  * add the spacer only when it fills the width
  * fully retrocompatible with showNavigationButtons as bool
  * more granularity to globalToolBar.showNavigationButtons
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * [ActionTextField] Make action glow on press
  * Remove ifdef for Qt 5.11 since that is now the required version
  * support text mode and position
  * mouseover effect for breadcrumb on desktop
  * Fix typo in documentation
  * enforce a minimum height of 2 gridunits
  * Set SwipeListItem implicitHeight to be the maximum of content and actions
  * Hide tooltip when PrivateActionToolButton is pressed
  * Remove accidentally slipped back traces of cmake code for Plasma style
  * ColumnView::itemAt
  * force breeze-internal if no theme is speacified
  * correct navigation on left pinned page
  * keep track of the space covered by pinned pages
  * show a separator when in left sidebar mode
  * in single column mode, pin has no effect
  * first semi working prototype of pinning
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * [ActionTextField] Make QML tooltip consistent
  * base on height for items that should have a top padding (kde#405614)
  * Compress color changes without a QTimer
  * [FormLayout] Use even top and bottom spacing for separator (kde#405614)
  * ScrollablePage: Make sure the scrolled view gets the focus when it's set
  * Improve keyboard-only usage of the toolbar (kde#403711)
  * make the recycler a FocusScope
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * dd the new files to the pri file
  * [aboutpage] hide Authors header if there are no authors
  * Update qrc.in to match .qrc (missing ActionMenuItem)
  * fix formatting in android build instructions
  * DesktopIcon -> Icon
  * Make sure we don't squeeze out the ActionButton (kde#406678)
  * make it work
  * single event filter in a singleton
  * Revert "make it an attached property"
  * make it an attached property
  * final api, documentation++
  * add blockTargetWheel property
  * add a wheelhandler event filter
  * fix implicitWidth
  * remove all the custom mouse wheel handling
  * remove extra debug
  * propagate hints to ColumnView and PageRow
  * ensure layout is done right after component.oncompleted
  * Pages: export correct contentHeight/implicit sizes
  * [ColumnView] Also check for index in child filter...
  * [ColumnView] Don't let mouse back button go back beyond first page
  * header has immediately the proper size
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Too many changes to list here
* Fri Mar 15 2019 lbeltrame@kde.org
- Update to 5.56.1
  * New bugfix release
- Changes since 5.56.0:
  * avoid parenting OverlaySheet to ColumnView
  * hide breadcrumb on pages that don't want a toolbar (kde#404481)
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Too many changes to list here
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * raise only colored buttons (kde#403807)
  * fix height
  * same margins sizing policy as the other list items
  * === operators
  * support for the concept of expandible items
  * don't clear when replacing all the pages
  * horizontal padding is double than vertical
  * take padding into account to compute size hints
  * [kirigami] Do not use light font styles for headings (2/3)
  * Unbreak the AboutPage layout on smaller devices
  * stopatBounds for breadcrumb flickable
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Too many changes to list here
* Mon Dec 10 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Fix warning
  * DelegateRecycler: Fix build with strict iterators
  * DelegateRecycler: Don't create a new propertiesTracker for every delegate
  * Move the about page from Discover to Kirigami
  * update versions
  * antialiasing only when position != 0
  * make sure scroll views are pixel aligned
  * Make it possible to fallback to a different icon
  * hide context drawer when there is a global toolbar
  * ensure all items are laid out (kde#400671)
  * center FormLayout
  * change index on pressed, not on clicked (kde#400518)
  * more consistency between toolbar and breadcrumb titles
  * fix separators behavior
  * new text sizes for Headings
  * sidebar drawers don't move global headers/footers
  * on big devices, just take 95%% of the space
- Dropped patches, now upstream:
  * 0001-make-sure-scroll-views-are-pixel-aligned.patch
* Tue Nov 27 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to workaround visual glitches with unaligned text (boo#1117346, kde#401174):
  * 0001-make-sure-scroll-views-are-pixel-aligned.patch
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Too many changes to list here
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Require the library in the -devel subpackage
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * fix-build-with-gcc48.patch
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * support dynamically adding and removing title (kde#396417)
  * introduce actionsVisible (kde#396413)
  * Fix documentation typo
  * adapt margins when scrollbar appears/disappear
  * better management of the size (kde#396983)
  * Optimise setting up the palette
  * AbstractApplciationItem shouldn't have its own size, only implicit
  * new signals pagePushed/pageRemoved
  * fix logic
  * add ScenePosition element (kde#396877)
  * No need to emit the intermediary palette for every state
  * hide->show
  * Collapsible Sidebar Mode
  * kirigami_package_breeze_icons: don't treat lists as elements
  * fix searc/replace regexp (kde#396294)
  * animating a color produces a rater unpleasant effect (kde#389534)
  * color focused item for keyboard navigation
  * remove quit shortcut
  * Remove long-time deprecated Encoding=UTF-8 from desktop format file
  * fix toolbar size (kde#396521)
  * fix handle sizing
  * Honor BUILD_TESTING
  * Show icons for actions that have an icon source rather than an icon name
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Too many changes to list here
* Wed Jun 13 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it compile with gcc 4.8 on
  Leap 42.3
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Show action.main more prominently on the ToolBarApplicationHeader
  * Allow Kirigami build without KWin tablet mode dependency
  * correct swipefilter on RTL
  * correct resizing of contentItem
  * fix --reverse behavior
  * share contextobject to always access i18n
  * make sure tooltip is hidden
  * make sure to not assign invalid variants to the tracked proeprties
  * fix a couple of warnings
  * handle not a MouseArea, dropped() signal
  * no hover effects on mobile
  * proper icons overflow-menu-left and right
  * remove useless debug
  * not hoverenabled
  * Drag handle to reorder items in a ListView
  * Add Settings class to API documentation
  * Use Mnemonics on the toolbar buttons
  * Use override
  * Added missing files in QMake's .pri
  * [API dox] Fix Kirigami.InlineMessageType -> Kirigami.MessageType
  * fix applicationheaders in applicationitem
  * fix build on macos/ios
  * Fix warnings
  * Remove wrong warning
  * Don't allow showing/hiding the drawer when there's no handle (kde#393776)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Too many changes to list here
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Too many changes to list here
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Too many changes to list here
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Too many changes to list here
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Add recently added file to .qrc
  * keep the flickable interactive
  * proper prefix for icons as well
  * upgrade version
  * more docs
  * fix form sizing
  * Fixed qmake build
  * read wheelScrollLines from kdeglobals if existing
  * add a prefix for kirigami files to avoid conflicts
  * some static linking fixes
  * move plasma styles to plasma-framework
  * Use single quotes for matching characters + QLatin1Char
  * FormLayout
* Wed Jan  3 2018 fabian@ritter-vogt.de
- Remove baselibs.conf:
  * Not needed
* Sun Dec 17 2017 lbeltrame@kde.org
  * Update to 5.41.0
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * syntax working on older Qt 5.7 (kde#385785)
  * stack the overlaysheet differently (kde#386470)
  * Show the delegate highlighted property as well when there's no focus
  * preferred size hints for the separator
  * correct Settings.isMobile usage
  * Allow applications to be somewhat convergent on a desktop-y system
  * Make sure the content of the SwipeListItem doesn't overlap the handle
  * check page.actions for null
  * use a Dialog
  * Overlaysheet's scrollview is always ointeractive
  * Add categories in gallery desktop file (kde#385430)
  * Update the kirigami.pri file
  * use the non installed plugin to do the tests
  * partly revert 72c01208fe79
  * Deprecate Kirigami.Label
  * Port gallery example use of Labels to be consistently QQC2
  * Port Kirigami.Controls uses of Kirigami.Label
  * remove useless debug
  * make the scrollarea interactive on touch events
  * Move the git find_package call to where it's used
  * default to transparent listview items
  * Add 'Introduction' section to README.md - this is needed for inqlude script to create a proper manifest file for inqlude.org website, used information from metainfo.yaml/Mainpage.dox
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Too many changes to list here
* Tue Sep 19 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Too many changes to list here
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * None
* Wed May  3 2017 fabian@ritter-vogt.de
- Update to 2.1.1:
  * Ships with correct translation files now
* Sat Apr 29 2017 fabian@ritter-vogt.de
- Update to 2.1.0:
  * No upstream changelog provided, visit:
    https://dot.kde.org/2017/04/28/kirigami-21-out
- Remove patches, now upstream:
  * fix-license.patch
* Fri Apr 21 2017 fabian@ritter-vogt.de
- Remove obsolete BuildReq
- Add libqt5-qtquickcontrols2 runtime dependency
* Mon Jan 23 2017 fabian@ritter-vogt.de
- Add upstream patch to fix licensing issues (kde#375344):
  * fix-license.patch
* Tue Dec 13 2016 fabian@ritter-vogt.de
- New kirigami2 package, copy of kirigami, which is now kirigami 1.1
